# camml
A package of ML components for CTL field camera systems. 

# Dependencies

Depends on Google's pycoral package. Instructions for installing this
at:

https://coral.ai/docs/accelerator/get-started/#pycoral-on-linux